@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 use Module::ScanDeps::Static;
 
@@ -12,6 +12,6 @@ __PACKAGE__->main();
 sub main {
 
   exit Module::ScanDeps::Static->main;
-}
+} ## end sub main
 
 1;
